@@ -17,7 +17,7 @@ require AutoLoader;
    NameSpace_URL
    NameSpace_X500
 );
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 
 # Preloaded methods go here.
@@ -77,23 +77,28 @@ Unique Identifiers (GUIDs/UUIDs).
 
 =head1 DESCRIPTION
 
-   This module provides a framework for generating UUIDs (Universally Unique
-   Identifiers, also known as GUIDs (Globally Unique Identifiers). A UUID is
-   128 bits long, and is guaranteed to be different from all other UUIDs/GUIDs
-   generated until 3400 A.D. UUIDs were originally used in the Network Computing 
-   System (NCS) and later in the Open Software Foundation's (OSF) Distributed 
-   Computing Environment. Currently many different technologies rely on UUIDs to
-   provide unique identity for various software components, Microsoft COM/DCOM
-   for instance, uses GUIDs very extensively to uniquely identify classes, 
-   applications and components across network-connected systems.
-   The algorithm for UUID generation, used by this extension, is described in the
-   Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz. It provides
-   reasonably efficient and reliable framework for generating UUIDs and supports
-   fairly high allocation rates - 10 million per second per machine, and therefore,
-   is suitable for identifying both - extremely short-lived and very persistent 
-   objects on a given system as well as across the network.
-   This modules provides several methods to create a UUID:
+This module provides a framework for generating UUIDs (Universally Unique
+Identifiers, also known as GUIDs (Globally Unique Identifiers). A UUID is 128
+bits long, and is guaranteed to be different from all other UUIDs/GUIDs
+generated until 3400 CE.
 
+UUIDs were originally used in the Network Computing System (NCS) and later in
+the Open Software Foundation's (OSF) Distributed Computing Environment.
+Currently many different technologies rely on UUIDs to provide unique identity
+for various software components. Microsoft COM/DCOM for instance, uses GUIDs
+very extensively to uniquely identify classes, applications and components
+across network-connected systems.
+
+The algorithm for UUID generation, used by this extension, is described in the
+Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz
+(L<http://www.globecom.net/ietf/draft/draft-leach-uuids-guids-01.html>). It
+provides reasonably efficient and reliable framework for generating UUIDs and
+supports fairly high allocation rates -- 10 million per second per machine --
+and therefore is suitable for identifying both extremely short-lived and very
+persistent objects on a given system as well as across the network.
+
+This modules provides several methods to create a UUID:
+ 
    # creates binary (16 byte long binary value) UUID.
    $ug->create();
    $ug->create_bin();
@@ -101,21 +106,21 @@ Unique Identifiers (GUIDs/UUIDs).
    # creates binary (16-byte long binary value) UUID based on particular
    # namespace and name string.
    $ug->create_from_name(<namespace>, <name>);
-   $ug->create_from_name_bin(<namespace>, <name>); 
+   $ug->create_from_name_bin(<namespace>, <name>);
 
    # creates UUID string, using conventional UUID string format,
-   # such as: 4162F712-1DD2-11B2-B17E-C09EFE1DC403 
+   # such as: 4162F712-1DD2-11B2-B17E-C09EFE1DC403
    $ug->create_str();
    $ug->create_from_name_str(<namespace>, <name>);
 
    # creates UUID string as a hex string,
-   # such as: 0x4162F7121DD211B2B17EC09EFE1DC403 
+   # such as: 0x4162F7121DD211B2B17EC09EFE1DC403
    $ug->create_hex();
    $ug->create_from_name_hex(<namespace>, <name>);
 
    # creates UUID string as a Base64-encoded string
    $ug->create_b64();
-   $ug->create_from_name_b64(<namespace>, <name>);   
+   $ug->create_from_name_b64(<namespace>, <name>);
 
    Binary UUIDs can be converted to printable strings using following methods:
 
@@ -132,7 +137,7 @@ Unique Identifiers (GUIDs/UUIDs).
 
    # recreate binary UUID from string
    $ug->from_string(<uuid>);
-   $ug->from_hexstring(<uuid>);	
+   $ug->from_hexstring(<uuid>);
 
    # recreate binary UUID from Base64-encoded string
    $ug->from_b64string(<uuid>);
@@ -143,7 +148,7 @@ Unique Identifiers (GUIDs/UUIDs).
    # than, equals to, or greater than uuid2
    $ug->compare(<uuid1>, <uuid2>);
 
-   Examples:
+Examples:
 
    use Data::UUID qw(:all);
 
@@ -155,18 +160,30 @@ Unique Identifiers (GUIDs/UUIDs).
 
 =head2 EXPORT
 
-   The module allows exporting of several standard namespace UUIDs:
-      NameSpace_DNS
-      NameSpace_URL
-      NameSpace_OID
-      NameSpace_X500
+The module allows exporting of several standard namespace UUIDs:
 
+=over
+
+=item NameSpace_DNS
+
+=item NameSpace_URL
+
+=item NameSpace_OID
+
+=item NameSpace_X500
+
+=back
+ 
 =head1 AUTHOR
 
-Alexander Golomshtok<lt>golomshtok_alexander@jpmorgan.com<gt>
+Alexander Golomshtok<agolomsh@cpan.org>
 
 =head1 SEE ALSO
 
-L<perl>.
-
+The Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz:
+L<http://www.globecom.net/ietf/draft/draft-leach-uuids-guids-01.html>
+"Primary Key Reengineering Projects: The Problem" by Tom Johnston
+L<http://www.dmreview.com/editorial/dmreview/print_action.cfm?EdID=1866>
+"Primary Key Reengineering Projects: The Solution" by Tom Johnston
+L<http://www.dmreview.com/editorial/dmreview/print_action.cfm?EdID=2004>
 =cut
